aboutsummaryrefslogtreecommitdiff
path: root/src/versionbits.h
diff options
context:
space:
mode:
authorAnthony Towns <aj@erisian.com.au>2021-11-12 07:14:21 +1000
committerAnthony Towns <aj@erisian.com.au>2022-01-15 04:37:56 +1000
commit240cad09baefcf363cce36a4b2795122adfce27f (patch)
tree3ca74e49bb15731b8649405d1060367d425b6696 /src/versionbits.h
parent376c0c6dae2bebbb3e1352377e71fb1996d09f64 (diff)
downloadbitcoin-240cad09baefcf363cce36a4b2795122adfce27f.tar.xz
rpc: getdeploymentinfo: include signalling info
Diffstat (limited to 'src/versionbits.h')
-rw-r--r--src/versionbits.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/src/versionbits.h b/src/versionbits.h
index 34fba47b5f..81e6bcf0d5 100644
--- a/src/versionbits.h
+++ b/src/versionbits.h
@@ -64,8 +64,10 @@ protected:
virtual int Threshold(const Consensus::Params& params) const =0;
public:
- /** Returns the numerical statistics of an in-progress BIP9 softfork in the period including pindex */
- BIP9Stats GetStateStatisticsFor(const CBlockIndex* pindex, const Consensus::Params& params) const;
+ /** Returns the numerical statistics of an in-progress BIP9 softfork in the period including pindex
+ * If provided, signalling_blocks is set to true/false based on whether each block in the period signalled
+ */
+ BIP9Stats GetStateStatisticsFor(const CBlockIndex* pindex, const Consensus::Params& params, std::vector<bool>* signalling_blocks = nullptr) const;
/** Returns the state for pindex A based on parent pindexPrev B. Applies any state transition if conditions are present.
* Caches state from first block of period. */
ThresholdState GetStateFor(const CBlockIndex* pindexPrev, const Consensus::Params& params, ThresholdConditionCache& cache) const;
@@ -82,8 +84,10 @@ private:
ThresholdConditionCache m_caches[Consensus::MAX_VERSION_BITS_DEPLOYMENTS] GUARDED_BY(m_mutex);
public:
- /** Get the numerical statistics for a given deployment for the signalling period that includes pindex. */
- static BIP9Stats Statistics(const CBlockIndex* pindex, const Consensus::Params& params, Consensus::DeploymentPos pos);
+ /** Get the numerical statistics for a given deployment for the signalling period that includes pindex.
+ * If provided, signalling_blocks is set to true/false based on whether each block in the period signalled
+ */
+ static BIP9Stats Statistics(const CBlockIndex* pindex, const Consensus::Params& params, Consensus::DeploymentPos pos, std::vector<bool>* signalling_blocks = nullptr);
static uint32_t Mask(const Consensus::Params& params, Consensus::DeploymentPos pos);